
/******************************************************************************
*       Copyright (C) 2005 Freescale Semiconductor, Inc.
*       All Rights Reserved
*
* Filename:     DEMO9S08QD4_app.c
* Author:       r1aald
* Revision:     1.0
*
* Description:  This application code can be used to demonstrate the features 
*                of the QD4 Demo board. This code configures Analog to digital 
*                readings on PTA0 (RV1 Potentiometer) and PTA1 (RZ1 photo sensor)
*                SW1 configures a reading of the Potentiometer, SW2 a reading of
*                the photosensor. The ADC data is examined and if the result is 
*                lower than 0x1ff LED1 is turned on to indicate an alarm state.
*
*
* Notes:        Also serves as an example for the 9S08QD4 demo board.
*               Created using CodeWarrior 5.1 for HC(S)08.
******************************************************************************/


#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */
#include "demo9S08QD4.h" /*include demo board declarations */

#define Enter_Wait asm(wait)
//#define BKGD_DISABLED

static char ADC_val_H;
static char ADC_val_L;
static int  ADC_val = 0;
static char channel = 0;	 

void main(void) {
  
  EnableInterrupts; /* enable interrupts */
  
  #ifdef BKGD_DISABLED
  SOPT1_BKGDPE = 0;
  #endif
  
  ICSC2_BDIV = 3;   //Set bus divide to divide by 8
  
  LED1 =0;
  LED1_DDR = 1;
  
  /** ADC Init*/
  ADC1SC1 = 0x5F;  /* Enable interrupts 
                     Disable continuous conversions
                     Disable ADC by setting all ADCH bits */
  ADC1SC2 = 0x00;  /* Select S/W trigger
         						 Disable compare function */
  ADC1CFG = 0x0B; 	/* ADIV=input clock/8
                     ADLSMP=long sample time
                     MODE=10bit conversion
                     ADICLK=bus clock */
  APCTL1 = 0x03;  // Enable pins 0-1 as ADC inputs
 
  
  /** KBI Set Up foe SW1 & SW2 */
  KBIPE_KBIPE2 =1; /* Enable Keyboard Pin */                                  
  KBIPE_KBIPE3 =1; /* Enable Keyboard Pin */                                  

  
  KBISC_KBIE =  1;  /* Enable Keyboard Interrupts */
  KBISC_KBACK = 1;  /* Clear Pending Keyboard Interrupts */
  
  PTAPE_PTAPE2 = 1; /* Enable Pullup for Keyboard pin */
  PTAPE_PTAPE3 = 1; /* Enable Pullup for Keyboard pin */
   
   
   
    /** timer_setup */
  TPMMOD = 0x2000;
  TPMSC_PS = 0x07; //Set Div 128 prescaler
  TPMSC_TOIE = 1;  //Enable Timer Overflow Interrupt
 // TPMSC_CLKSx = 1; //Select Bus clock and start the timer           
  
  for(;;) {
  
   ADC1SC1_ADCH = channel;
   Enter_Wait;
   
    __RESET_WATCHDOG(); /* feeds the dog */
    
    
  } /* loop forever */
}  /* please make sure that you never leave this function */



/** KBI ISR */
interrupt 18 void   KBI_ISR(void) {  
//Check wich SW was pressed


  if (!SW1){
  
   channel =0;
  
  }else if (!SW2){
   channel = 1;
  }
  
  KBISC_KBACK = 1; /* Clear Pending Keyboard Interrupts */
}

//ADC ISR
interrupt 19 void   ADC_ISR(void) {
  ADC_val_H = ADC1RH;
  ADC_val_L = ADC1RL;
  
  ADC_val =( ADC_val_H  * 256) + ADC_val_L;
  
  if (ADC_val>=0x1ff){
  
  LED1 = 1;
  } else if (ADC_val <= 0x1fe){
  LED1 = 0;
  }
  
}

/** TIM1OVFL_ISR - ISR that provides the timebase. */
interrupt 7 void   TIM1OVFL_ISR(void) {
      /* clear TOF */
    
      LED1 = ~LED1;    /* toggle Port */ 
      TPMSC_TOF = 0;
      
      
  
}

